@@ -13,6 +13,7 @@ Usage::
 """
 from typing import Any, Dict, List, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_sso_oidc.type_defs import (
@@ -42,14 +43,15 @@ class Exceptions:
 
 class SSOOIDCClient:
     """
-    [SSOOIDC.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sso-oidc.html#SSOOIDC.Client)
+    [SSOOIDC.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/sso-oidc.html#SSOOIDC.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
         """
 
     def create_token(
@@ -64,7 +66,7 @@ class SSOOIDCClient:
         redirectUri: str = None,
     ) -> CreateTokenResponseTypeDef:
         """
-        [Client.create_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
+        [Client.create_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
         """
 
     def generate_presigned_url(
@@ -75,19 +77,19 @@ class SSOOIDCClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
         """
 
     def register_client(
         self, clientName: str, clientType: str, scopes: List[str] = None
     ) -> RegisterClientResponseTypeDef:
         """
-        [Client.register_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
+        [Client.register_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
         """
 
     def start_device_authorization(
         self, clientId: str, clientSecret: str, startUrl: str
     ) -> StartDeviceAuthorizationResponseTypeDef:
         """
-        [Client.start_device_authorization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
+        [Client.start_device_authorization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
         """
